@@ -102,7 +102,7 @@ use utf8;
 use FindBin;
 use POSIX 'strftime';
 
-our $VERSION = '0.0.7'; # VERSION
+our $VERSION = '0.0.8'; # VERSION
 
 use Moose;
 use MooseX::AttributeShortcuts;
@@ -189,6 +189,17 @@ default is 1 (enable)
 =cut
 has use_report => (is => 'rw', default => 1);
 
+=item use_report_log
+
+set/get use_report_log option (Bool)
+
+report to log
+
+default is 0 (false)
+=cut
+has use_report_log => (is => 'rw', default => 0);
+
+
 =item log_dir
 
 set/get log dir (String)
@@ -444,7 +455,7 @@ sub _fetch_reports {
   }
   rmdir $report_path;
 
-  Rex::Logger::info( join("\n", map { Dump($_) } @reports) );
+  Rex::Logger::info( join("\n", map { Dump($_) } @reports) ) if $self->use_report_log;
   return @reports;
 }
 
